@@ -1,5 +1,5 @@
 from django.contrib import admin
-from .models import Number, Trunk, Cluster, DevicePool
+from .models import Number, Trunk, UCCluster, DevicePool
 
 
 @admin.register(Number)
@@ -10,9 +10,9 @@ class NumPlanAdmin(admin.ModelAdmin):
 class TrunkPlanAdmin(admin.ModelAdmin):
     list_display = ("trunk", "tenant", "destination", "provider", "region", "description")
 
-@admin.register(Cluster)
-class ClusterPlanAdmin(admin.ModelAdmin):
-    list_display = ("cluster", "tenant", "description", "publisher", "subscriber1", "subscriber2", "subscriber3", "subscriber4", "tftp1", "tftp2")
+@admin.register(UCCluster)
+class UCClusterPlanAdmin(admin.ModelAdmin):
+    list_display = ("UCCluster", "tenant", "description", "publisher", "subscriber1", "subscriber2", "subscriber3", "subscriber4", "tftp1", "tftp2")
 
 @admin.register(DevicePool)
 class DevicePoolPlanAdmin(admin.ModelAdmin):
