@@ -12,8 +12,8 @@ menu_items = (
         buttons=()
     ),
     PluginMenuItem(
-        link='plugins:ucbox_plugin:cluster_list_view',
-        link_text='Clusters',
+        link='plugins:ucbox_plugin:UCCluster_list_view',
+        link_text='UCClusters',
         buttons=()
     ),
     PluginMenuItem(
